@@ -1,4 +1,4 @@
-# $Id: HiClimR2nc.R, v2.1.3 2019/01/10 12:00:00 hsbadr EPS JHU           #
+# $Id: HiClimR2nc.R, v2.1.4 2019/01/20 12:00:00 hsbadr EPS JHU           #
 #-------------------------------------------------------------------------#
 # This function is a part of HiClimR R package.                           #
 #-------------------------------------------------------------------------#
@@ -42,6 +42,7 @@
 #   2.1.1   |  01/02/19  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
 #   2.1.2   |  01/04/19  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
 #   2.1.3   |  01/10/19  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   2.1.4   |  01/20/19  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
 #-------------------------------------------------------------------------#
 # COPYRIGHT(C) 2013-2019 Earth and Planetary Sciences (EPS), JHU.         #
 #-------------------------------------------------------------------------#
@@ -150,7 +151,4 @@ HiClimR2nc <-
     
     #gc()
     return(ncout)
-    
-    # close the file, writing data to disk
-    nc_close(ncout)
   }
